import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/constants.dart';
import 'package:softcorp_flutter_core/default_form_field/default_form_field.dart';
import 'package:softcorp_flutter_core/default_header_card/default_header_card.dart';
import 'package:softcorp_flutter_core/default_list_form/default_list_form.dart';
import 'package:softcorp_flutter_core/default_multi_select/default_multi_select.dart';
import 'package:softcorp_flutter_core/details_profile_card/default_profile_card.dart';
import 'package:softcorp_flutter_core/footer/footer_example.dart';
import 'package:softcorp_flutter_core/split_screen/split_screen.dart';
import 'package:websafe_svg/websafe_svg.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Softcorp Core Demo',
      home: SplitScreen(
        footer: const SizedBox(height: 100, child: FooterExample()),
        leftCornerLogo: Column(
          children: <Widget>[
            Image.asset(
              "assets/logos/softcorp-logo-white.png",
              height: 50,
            ),
            const SizedBox(height: 5),
            const Text(
              "Connect",
              style: TextStyle(
                fontSize: 20,
                fontWeight: FontWeight.w600,
                color: Colors.white,
              ),
            )
          ],
        ),
        leftChild: Container(
          height: 300,
          width: 300,
          color: Colors.orangeAccent,
        ),
        rightChild: Column(
          children: [
            const DefaultHeaderCard(
              backgroundColor: defaultCardColor,
              child: Text("Test 1"),
              title: "Title for Default Header Card",
              subtitle: "Subtitle for Default Header Card",
              icon: Icon(
                  Icons.home_work_outlined,
                color: Colors.white,
                size: 50,
              ),
            ),
            DefaultHeaderCard(
              backgroundColor: defaultCardColor,
              child: const Text("Test 1"),
              title: "Title for Default Header Card",
              subtitle: "Subtitle for Default Header Card",
              icon: Image.asset(
                "assets/logos/softcorp-logo-white.png",
                height: 60,
              ),
            ),
            DefaultProfileCard(
              height: 300,
              title: "This is not a title",
              subTitle: "This is not a subtitle",
              tabBarEnabled: true,
              tabs: [
                ProfileDetailsTab(
                  icon: Icons.business,
                  name: "Tab 1",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 1");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.money_rounded,
                  name: "Tab 2",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 2");
                  },
                ),
                ProfileDetailsTab(
                  icon: Icons.map_rounded,
                  name: "Tab 3",
                  onPressed: () {
                    // ignore: avoid_print
                    print("tab 3");
                  },
                ),
              ],
              actionsEnabled: true,
              actionItemsLabelValueMap: const {
                "Key 1": "Value 1",
                "Key 2": "Value 2",
                "Key 3": "Value 3",
              },
              onSelectActionItem: (val) {
                // ignore: avoid_print
                print(val);
              },
              icon: const Icon(
                Icons.business_rounded,
                color: defaultBackgroundColor,
              ),
            ),
            DefaultFormField(
                textEditingController: TextEditingController(),
                textInputType: TextInputType.text,
                hint: "This is some hint",
                label: "My Label"),
            DefaultMultiSelect(
                items: const {
                  "Item 1": "Item 1",
                  "Item 2": "Item 2",
                  "Item 3": "Item 3",
                },
                title: "Multi-select title",
                onConfirm: (values) {
                  // ignore: avoid_print
                  for (var element in values) {
                    print(element);
                  }
                }),
            DefaultListForm(
                textInputType: TextInputType.number,
                label: "Multi Form Field",
                hint: "Here is no hint",
                controller: DefaultListFormController()),
          ],
        ),
      ),
    );
  }
}
