import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/responsive/responsive.dart';

class SplitScreen extends StatelessWidget {
  final ImageProvider? backgroundImage;
  final Widget? leftChild;
  final Widget? rightChild;
  final Widget? leftCornerLogo;
  final Widget? footer;

  const SplitScreen({
    Key? key,
    this.backgroundImage,
    this.leftChild,
    this.rightChild,
    this.leftCornerLogo,
    this.footer,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Scaffold(
      body: SizedBox(
        width: size.width,
        height: size.height,
        child: Stack(
          children: [
            Row(
              children: [
                Expanded(
                  flex: Responsive.isMobile(context) ? 0 : 2,
                  child: Container(
                    height: double.infinity,
                    decoration: BoxDecoration(
                      image: DecorationImage(
                        image: backgroundImage ??
                            const AssetImage("assets/covers/cover1.jpg"),
                        fit: BoxFit.cover,
                      ),
                    ),
                    child: Responsive.isMobile(context)
                        ? const SizedBox()
                        : Center(
                            child: leftChild,
                          ),
                  ),
                ),
                Expanded(
                  flex: 2,
                  child: Container(
                    height: double.infinity,
                    child: SingleChildScrollView(
                      child: Column(
                        crossAxisAlignment: CrossAxisAlignment.center,
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          Responsive.isMobile(context)
                              ? Padding(
                                  padding: const EdgeInsets.all(32),
                                  child: Align(
                                      alignment: Alignment.topLeft,
                                      child: leftCornerLogo),
                                )
                              : const SizedBox(),
                          rightChild ?? const SizedBox(),
                        ],
                      ),
                    ),
                    decoration: Responsive.isMobile(context)
                        ? const BoxDecoration(
                            image: DecorationImage(
                              image: AssetImage("assets/covers/cover1.jpg"),
                              fit: BoxFit.cover,
                            ),
                          )
                        : const BoxDecoration(),
                  ),
                ),
              ],
            ),
            !Responsive.isMobile(context)
                ? Align(
                    alignment: Alignment.topLeft,
                    child: Padding(
                      padding: const EdgeInsets.all(32),
                      child: leftCornerLogo,
                    ),
                  )
                : const SizedBox(),
            Align(
              alignment: Alignment.bottomCenter,
              child: footer ?? const SizedBox(),
            ),
          ],
        ),
      ),
    );
  }
}
